/// <reference types="react" />
import * as React$1 from 'react';
import React__default, { MouseEvent as MouseEvent$1, ReactNode, ChangeEventHandler, PropsWithChildren } from 'react';

type AvatarSizes = "small" | "medium" | "large";
interface AvatarProps {
    src: string;
    size?: AvatarSizes;
    customSize?: React.CSSProperties["width"];
    alt?: HTMLImageElement["alt"];
    asText?: boolean;
    rounded?: boolean;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Avatar: ({ alt, size, src, asText, customClass, customStyles, customSize, }: AvatarProps) => React__default.JSX.Element;

type BadgeVariants = "dashed" | "ghost" | "outlined";
type BadgeThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type BadgeSizes = "small" | "medium" | "large";
interface BadgeProps {
    variant?: BadgeVariants;
    theme?: BadgeThemes;
    children?: React__default.ReactNode | string;
    size?: BadgeSizes;
    customClass?: string;
    customStyles?: React__default.CSSProperties;
}

declare const Badge: ({ variant, theme, children, size, customStyles, customClass, }: BadgeProps) => React__default.JSX.Element;

type BoxVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type BoxTextColor = "dark" | "light" | "darker" | "lighter";
interface BoxProps {
    bgColor?: BoxVariants;
    textColor?: BoxTextColor;
    centered?: boolean;
    width?: React.CSSProperties["width"];
    height?: React.CSSProperties["height"];
    padding?: React.CSSProperties["margin"];
    margin?: React.CSSProperties["margin"];
    borderRadius?: React.CSSProperties["borderRadius"];
    flex?: boolean;
    flexDirection?: React.CSSProperties["flexDirection"];
    justifyContent?: React.CSSProperties["justifyContent"];
    alignItems?: React.CSSProperties["alignItems"];
    flexWrap?: React.CSSProperties["flexWrap"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    children?: React.ReactNode;
    gridSpan?: {
        row?: number;
        col?: number;
    };
}

declare const Box: ({ width, children, padding, margin, height, bgColor, borderRadius, customClass, customStyles, centered, textColor, gridSpan, flexWrap, alignItems, flex, flexDirection, justifyContent, }: BoxProps) => React__default.JSX.Element;

type ButtonThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type ButtonVariants = "filled" | "outlined" | "ghost";
type ButtonTypes = "submit" | "reset" | "button";
type ButtonSizes = "small" | "medium" | "large";
interface ButtonState {
    disabled?: boolean;
}
interface ButtonProps {
    theme?: ButtonThemes;
    variant?: ButtonVariants;
    type?: ButtonTypes;
    size?: ButtonSizes;
    onClick?: (event?: MouseEvent$1<HTMLButtonElement>) => void;
    state?: ButtonState;
    children?: React.ReactNode;
    customClass?: string;
    customStyles?: React.CSSProperties;
    buttonProps?: React.ButtonHTMLAttributes<HTMLButtonElement>;
}

declare const Button: ({ theme, size, variant, type, onClick, state, children, customClass, customStyles, buttonProps, }: ButtonProps) => React__default.JSX.Element;

type CheckboxState = {
    disabled?: boolean;
};
type CheckboxSizes = "small" | "medium" | "large";
interface CheckboxProps {
    fieldKey: string;
    label?: string;
    size?: CheckboxSizes;
    defaultChecked?: boolean;
    state?: CheckboxState;
    width?: React.CSSProperties["width"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    customInputClass?: string;
    customInputStyles?: React.CSSProperties;
    customLabelClass?: string;
    customLabelStyles?: React.CSSProperties;
    onChange?: (event: React.ChangeEvent<HTMLInputElement>) => void;
    checkBoxProps?: React.InputHTMLAttributes<HTMLInputElement>;
    checkboxRef?: React.RefObject<HTMLInputElement>;
}

declare const Checkbox: ({ fieldKey, label, size, defaultChecked, onChange, state, width, customClass, customStyles, customInputStyles, customInputClass, customLabelClass, customLabelStyles, checkBoxProps, checkboxRef, }: CheckboxProps) => React__default.JSX.Element;

type DropdownVariant = "filled" | "outlined";
type DropdownSize = "small" | "medium" | "large";
type DropdownPosition = "bottomLeft" | "bottomRight" | "topLeft" | "topRight";
type DropdownTrigger = "click" | "hover";
interface DropdownProps {
    variant?: DropdownVariant;
    size?: DropdownSize;
    children?: React.ReactNode;
    anchor?: React.ReactNode;
    position?: DropdownPosition;
    trigger?: DropdownTrigger;
    clickOutside?: boolean;
    closeOnClick?: boolean;
    width?: React.CSSProperties["width"];
    customWrapperStyles?: React.CSSProperties;
    customWrapperClass?: string;
    customMenuStyles?: React.CSSProperties;
    customMenuClass?: string;
    menuProps?: React.HTMLAttributes<HTMLUListElement>;
}
interface DropdownItemProps {
    children?: ReactNode;
    noBreakWord?: boolean;
    onClick?: (event?: MouseEvent$1<HTMLLIElement, MouseEvent>) => void;
    disabled?: boolean;
    itemProps?: React.HTMLAttributes<HTMLLIElement>;
    closeOnClick?: boolean;
    centered?: boolean;
    readonly setShow?: React.Dispatch<React.SetStateAction<boolean>>;
    readonly trigger?: DropdownTrigger;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Dropdown: ({ anchor, menuProps, variant, size, children, position, clickOutside, closeOnClick, trigger, width, customWrapperStyles, customWrapperClass, }: DropdownProps) => React__default.JSX.Element;
declare const DropdownItem: ({ children, noBreakWord, onClick, setShow, customClass, customStyles, closeOnClick, trigger, centered, disabled, }: DropdownItemProps) => React__default.JSX.Element;
declare const DropdownSeparator: () => React__default.JSX.Element;

interface GridProps {
    cols?: React__default.CSSProperties["gridTemplateColumns"] | number;
    rows?: React__default.CSSProperties["gridTemplateRows"] | number;
    gap?: {
        row?: React__default.CSSProperties["rowGap"];
        col?: React__default.CSSProperties["columnGap"];
    };
    width?: React__default.CSSProperties["width"];
    padding?: React__default.CSSProperties["padding"];
    children?: React__default.ReactNode;
    customStyles?: React__default.CSSProperties;
    customClass?: string;
}

declare const Grid: ({ rows, cols, gap, width, padding, children, customClass, customStyles, }: GridProps) => React__default.JSX.Element;

type InputTypes = React__default.HTMLInputTypeAttribute;
type InputSizes = "small" | "medium" | "large";
type InputVariant = "outlined" | "filled";
type InputState = {
    disabled?: boolean;
};
interface InputProps {
    fieldKey?: string;
    type?: InputTypes;
    size?: InputSizes;
    variant?: InputVariant;
    width?: React__default.CSSProperties["width"];
    placeholder?: string;
    onChange?: React__default.ChangeEventHandler<HTMLInputElement>;
    customStyles?: React__default.CSSProperties;
    customClass?: string;
    state?: InputState;
    inputProps?: React__default.InputHTMLAttributes<HTMLInputElement>;
    inputRef?: React__default.RefObject<HTMLInputElement>;
}

declare const Input: ({ fieldKey, type, variant, placeholder, onChange, size, width, customClass, customStyles, state, inputProps, inputRef, }: InputProps) => React__default.JSX.Element;

type ModalFooterFunction = (id: string, onClose: () => void) => void;
type ModalFooterProps = ButtonProps[] | null;
interface ModalProps {
    id: string;
    title: string;
    children?: React.ReactNode;
    visible?: boolean;
    width?: React.CSSProperties["width"];
    zIndex?: React.CSSProperties["zIndex"];
    centered?: boolean;
    top?: React.CSSProperties["top"];
    left?: React.CSSProperties["left"];
    right?: React.CSSProperties["right"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    customWrapperClass?: string;
    customWrapperStyles?: React.CSSProperties;
    closable?: boolean;
    maskClosable?: boolean;
    destroyOnClose?: boolean;
    onClose?: () => void;
    onOk?: ModalFooterFunction;
    onCancel?: ModalFooterFunction;
    okText?: string;
    cancelText?: string;
    footer?: ModalFooterProps;
    customFooter?: React.ReactNode;
}

declare const Modal: ({ id, title, width, visible, zIndex, children, centered, maskClosable, onCancel, onClose, onOk, cancelText, okText, footer, customFooter, closable, customClass, customStyles, customWrapperClass, customWrapperStyles, destroyOnClose, top, left, right, }: ModalProps) => React__default.JSX.Element | null;

type ModalProviderProps = {
    children: React__default.ReactNode;
};
declare const ModalProvider: ({ children }: ModalProviderProps) => React__default.JSX.Element;

type ModalContextProps = {
    modals: ModalProps[];
    createModal: (modal: ModalProps) => void;
    openModal: (id: string) => void;
    closeModal: (id: string, shouldDestroy?: boolean) => void;
    hasModal: (id: string) => boolean;
    destroyModal: (id: string) => void;
    destroyAll: () => void;
};
declare const ModalContext: React$1.Context<ModalContextProps>;

type ToastTheme = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type ToastSize = "small" | "medium" | "large";
type ToastVariant = "filled";
type ToastPosition = "topLeft" | "topCenter" | "topRight" | "bottomLeft" | "bottomCenter" | "bottomRight";
interface ToastProps {
    id?: string;
    label: string;
    theme?: ToastTheme;
    variant?: ToastVariant;
    size?: ToastSize;
    duration?: number;
    loading?: boolean;
    closable?: boolean;
    zIndex?: React__default.CSSProperties["zIndex"];
    onClose?: () => void;
    customStyles?: React__default.CSSProperties;
    customClass?: string;
}

type ToastProviderProps = {
    children: React__default.ReactNode;
    stackable?: boolean;
    position?: ToastPosition;
    duration?: number;
};
declare const ToastProvider: ({ children, position, stackable, duration, }: ToastProviderProps) => React__default.JSX.Element;

interface OverlayProviderProps {
    children: React__default.ReactNode;
    ModalProviderProps?: Omit<ModalProviderProps, "children">;
    ToastProviderProps?: Omit<ToastProviderProps, "children">;
}
declare const OverlayProvider: ({ children, ModalProviderProps, ToastProviderProps, }: OverlayProviderProps) => React__default.JSX.Element;

type PaginationSizes = "small" | "medium" | "large";
type PaginationLabel = (props: {
    currentPage: number;
    totalItems: number;
    itemsPerPage: number;
}) => string;
type PaginationButtons = {
    previous?: boolean;
    next?: boolean;
    limit?: number;
};
interface PaginationProps {
    currentPage: number;
    totalPages: number;
    totalItems: number;
    itemsPerPage: number;
    simplePagination?: boolean;
    paginationButtons?: PaginationButtons;
    size?: PaginationSizes;
    justifyContent?: React.CSSProperties["justifyContent"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    onPageChange?: (page: number) => void;
    showPaginationLabel?: PaginationLabel;
}

declare const Pagination: ({ currentPage, itemsPerPage, onPageChange, totalItems, totalPages, justifyContent, showPaginationLabel, paginationButtons, customStyles, customClass, size, simplePagination, }: PaginationProps) => React__default.JSX.Element;

type RadioSizes = "small" | "medium" | "large";
type RadioState = {
    disabled?: boolean;
};
interface RadioProps {
    fieldKey: string;
    label: string;
    value: string;
    size?: RadioSizes;
    state?: RadioState;
    defaultChecked?: boolean;
    onChange?: (e: React.ChangeEvent<HTMLInputElement>) => void;
    radioProps?: React.InputHTMLAttributes<HTMLInputElement>;
    customClass?: string;
    customStyles?: React.CSSProperties;
    customLabelClass?: string;
    customLabelStyles?: React.CSSProperties;
    customInputClass?: string;
    customInputStyles?: React.CSSProperties;
    radioRef?: React.Ref<HTMLInputElement>;
}

declare const Radio: ({ fieldKey, size, onChange, label, defaultChecked, radioProps, state, value, customInputClass, customInputStyles, customLabelClass, customLabelStyles, customStyles, customClass, radioRef, }: RadioProps) => React__default.JSX.Element;

type SelectSizes = "small" | "medium" | "large";
type SelectVariants = "filled" | "outlined";
type SelectOption = {
    label: string;
    value: string;
    disabled?: boolean;
};
type SelectState = {
    disabled?: boolean;
};
interface SelectProps {
    fieldKey?: string;
    size?: SelectSizes;
    variant?: SelectVariants;
    placeholder?: string;
    width?: React.CSSProperties["width"];
    onChange?: ChangeEventHandler<HTMLSelectElement>;
    customStyles?: React.CSSProperties;
    customClass?: string;
    options?: SelectOption[];
    state?: SelectState;
    selectRef?: React.Ref<HTMLSelectElement>;
    selectProps?: React.HTMLProps<HTMLSelectElement>;
}

declare const Select: ({ customClass, customStyles, fieldKey, onChange, placeholder, size, variant, width, children, options, selectRef, state, selectProps, }: PropsWithChildren<SelectProps>) => React__default.JSX.Element;

type SkeletonSizes = "small" | "medium" | "large";
type SkeletonVariants = "round" | "paragraph" | "rect";
interface SkeletonProps {
    children: React.ReactNode;
    size?: SkeletonSizes;
    variant?: SkeletonVariants;
    rows?: number;
    width?: React.CSSProperties["width"];
    show?: boolean;
    active?: boolean;
    customClass?: string;
    customStyles?: React.CSSProperties;
}

declare const Skeleton: ({ children, size, width, rows, customClass, customStyles, active, show, variant, }: SkeletonProps) => React__default.JSX.Element;

type SpinnerSizes = "small" | "medium" | "large";
type SpinnerVariants = "circle";
type SpinnerThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
interface SpinnerProps {
    size?: SpinnerSizes;
    variant?: SpinnerVariants;
    theme?: SpinnerThemes;
    customSpeed?: React.CSSProperties["animationDelay"];
    customColor?: React.CSSProperties["borderColor"];
    customSize?: React.CSSProperties["width"];
    customStyles?: React.CSSProperties;
    customClass?: string;
}

declare const Spinner: ({ size, theme, variant, customSpeed, customClass, customSize, customStyles, customColor, }: SpinnerProps) => React__default.JSX.Element;

type TableOrder = "asc" | "desc";
type TableColumn = {
    header: string;
    key: string;
    orderActive?: boolean;
    order?: TableOrder;
    orderFn?: (column: TableColumn) => void;
};
type TableRow = {
    [key: string]: string | number | boolean | undefined;
};
type TableVariants = "bordered" | "default";
type TableSizes = "small" | "medium" | "large";
interface TableHeaderProps {
    children?: React.ReactNode;
    columns?: TableColumn[];
    gridTemplateColumns?: React.CSSProperties["gridTemplateColumns"];
    customHeaderClass?: string;
    customHeaderStyles?: React.CSSProperties;
}
interface TableBodyProps {
    children?: React.ReactNode;
    rows?: TableRow[];
    keys?: string[];
    gridTemplateColumns?: React.CSSProperties["gridTemplateColumns"];
    customBodyClass?: string;
    customBodyStyles?: React.CSSProperties;
    emptyValue?: string;
}
type TableState = {
    empty?: boolean;
    disabled?: boolean;
    loading?: boolean;
    spinnerProps?: SpinnerProps;
    emptyContent?: JSX.Element;
};
interface TableProps extends TableHeaderProps, Omit<TableBodyProps, "keys"> {
    variant?: TableVariants;
    size?: TableSizes;
    customClass?: string;
    customStyles?: React.CSSProperties;
    width?: React.CSSProperties["width"];
    height?: React.CSSProperties["height"];
    state?: TableState;
    customWrapperClass?: string;
    customWrapperStyles?: React.CSSProperties;
}

declare const TableHeader: ({ children, columns, gridTemplateColumns, customHeaderClass, customHeaderStyles, }: TableHeaderProps) => React__default.JSX.Element;
declare const TableBody: ({ children, rows, keys, gridTemplateColumns, emptyValue, customBodyClass, customBodyStyles, }: TableBodyProps) => React__default.JSX.Element;
declare const Table: ({ columns, children, rows, customBodyClass, customBodyStyles, customClass, customHeaderClass, customHeaderStyles, customStyles, width, variant, size, gridTemplateColumns, emptyValue, state, height, customWrapperClass, customWrapperStyles, }: TableProps) => React__default.JSX.Element;

type TextAreaVariants = "outlined" | "filled";
type TextAreaSizes = "small" | "medium" | "large";
type TextAreaState = {
    disabled?: boolean;
};
interface TextAreaProps {
    fieldKey?: string;
    variant?: TextAreaVariants;
    size?: TextAreaSizes;
    minRows?: number;
    rows?: number;
    defaultValue?: string;
    onChange?: (e: React.ChangeEvent<HTMLTextAreaElement>) => void;
    state?: TextAreaState;
    placeholder?: string;
    resize?: boolean;
    width?: React.CSSProperties["width"];
    customClass?: string;
    customStyles?: React.CSSProperties;
    textAreaProps?: React.TextareaHTMLAttributes<HTMLTextAreaElement>;
    textAreaRef?: React.RefObject<HTMLTextAreaElement>;
}

declare const TextArea: ({ fieldKey, variant, width, size, resize, rows, minRows, state, customClass, customStyles, placeholder, onChange, defaultValue, textAreaProps, textAreaRef, }: TextAreaProps) => React__default.JSX.Element;

declare const Toast: ({ id, label, loading, duration, theme, variant, size, closable, onClose, zIndex, customClass, customStyles, }: ToastProps) => React__default.JSX.Element;

type ToastContextProps = {
    toasts: ToastProps[];
    createToast: (toast: ToastProps) => void;
    removeToast: (id: string) => void;
    position?: ToastPosition;
};
declare const ToastContext: React$1.Context<ToastContextProps>;

type TooltipDirections = "top" | "bottom" | "left" | "right";
type TooltipThemes = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
interface TooltipProps {
    direction?: TooltipDirections;
    theme?: TooltipThemes;
    customClass?: string;
    customStyles?: React.CSSProperties;
    title: string;
    children?: React.ReactNode;
}

declare const Tooltip: ({ children, title, direction, customClass, customStyles, theme, }: TooltipProps) => React__default.JSX.Element;

type TopographyTypes = "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "subtitle-1" | "subtitle-2" | "body-1" | "body-2" | "caption" | "button" | "overline";
interface TopographyProps {
    children?: React__default.ReactNode;
    variant?: TopographyTypes;
    customClass?: string;
    customStyles?: React__default.CSSProperties;
}

declare const Topography: ({ variant, children, customClass, customStyles, }: TopographyProps) => React__default.ReactElement<any, string | React__default.JSXElementConstructor<any>>;

type LeSizes = "small" | "medium" | "large";
type LeVariants = "primary" | "secondary" | "success" | "danger" | "warning" | "default";
type LeSafeAny = any;
type LeClassNames = Record<string, (props?: LeSafeAny) => string>;

declare namespace index_d {
  export {
  };
}

type LeBreakpoints = "sm" | "md" | "lg" | "xl";
type LeBreakpointType = {
    breakpoint: LeBreakpoints;
};
/**
 * useBreakpoint hook
 *
 * A one-liner hook to get the current breakpoint based on the window.innerWidth
 * always updated when the window is resized.
 *
 *
 * @returns {LeBreakpointType} `sm | md | lg | xl`
 */
declare function useBreakpoint(): LeBreakpointType;

export { Avatar, AvatarProps, AvatarSizes, Badge, BadgeProps, BadgeSizes, BadgeThemes, BadgeVariants, Box, BoxProps, BoxTextColor, BoxVariants, Button, ButtonProps, ButtonSizes, ButtonState, ButtonThemes, ButtonTypes, ButtonVariants, Checkbox, CheckboxProps, CheckboxSizes, CheckboxState, Dropdown, DropdownItem, DropdownSeparator, Grid, GridProps, Input, InputProps, InputSizes, InputState, InputTypes, InputVariant, LeBreakpointType, LeBreakpoints, index_d as LeCSS, LeClassNames, LeSafeAny, LeSizes, LeVariants, Modal, ModalContext, ModalContextProps, ModalFooterFunction, ModalFooterProps, ModalProps, ModalProvider, ModalProviderProps, OverlayProvider, Pagination, PaginationButtons, PaginationLabel, PaginationProps, PaginationSizes, Radio, RadioProps, RadioSizes, RadioState, Select, Skeleton, SkeletonProps, SkeletonSizes, SkeletonVariants, Spinner, SpinnerProps, SpinnerSizes, SpinnerThemes, SpinnerVariants, Table, TableBody, TableBodyProps, TableColumn, TableHeader, TableHeaderProps, TableOrder, TableProps, TableRow, TableSizes, TableState, TableVariants, TextArea, TextAreaProps, TextAreaSizes, TextAreaState, TextAreaVariants, Toast, ToastContext, ToastContextProps, ToastPosition, ToastProps, ToastProvider, ToastProviderProps, ToastSize, ToastTheme, ToastVariant, Tooltip, TooltipDirections, TooltipProps, Topography, TopographyProps, TopographyTypes, useBreakpoint };
